# eric7.Plugins.VcsPlugins.vcsMercurial.HgMergeDialog

Module implementing a dialog to enter the data for a merge operation.

### Global Attributes

None

### Classes

HgMergeDialog | Class implementing a dialog to enter the data for a merge operation.

### Functions

None

## HgMergeDialog

Class implementing a dialog to enter the data for a merge operation.

### Derived from

QDialog, Ui_HgMergeDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgMergeDialog | Constructor
__updateOK | Private slot to update the OK button.
getParameters | Public method to retrieve the merge data.

### Static Methods

None

#### HgMergeDialog (Constructor)

HgMergeDialog(tagsList, branchesList, bookmarksList=None, parent=None)

Constructor

tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
bookmarksList (list of str)
  list of bookmarks
parent (QWidget)
  parent widget

#### HgMergeDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgMergeDialog.getParameters

getParameters()

Public method to retrieve the merge data.

Return:
  tuple naming the revision and a flag indicating a forced merge

Return Type:
  tuple of (str, bool)

Up